import * as ec2 from '@aws-cdk/aws-ec2';
import * as ecs from '@aws-cdk/aws-ecs';
import { Schedule } from '@aws-cdk/aws-events';
import { RetentionDays } from '@aws-cdk/aws-logs';
import { Construct } from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface RunTaskProps {
    /**
     * The VPC for the Amazon ECS task.
     *
     * @default - create a new VPC or use existing one
     * @stability stable
     */
    readonly vpc?: ec2.IVpc;
    /**
     * The Amazon ECS Cluster.
     *
     * @default - create a new cluster
     * @stability stable
     */
    readonly cluster?: ecs.ICluster;
    /**
     * The Amazon ECS Task definition for AWS Fargate.
     *
     * @stability stable
     */
    readonly task: ecs.FargateTaskDefinition;
    /**
     * run it at once(immediately after deployment).
     *
     * @default true
     * @stability stable
     */
    readonly runAtOnce?: boolean;
    /**
     * run the task with defined schedule.
     *
     * @default - no shedule
     * @stability stable
     */
    readonly schedule?: Schedule;
    /**
     * Log retention days.
     *
     * @default - one week
     * @stability stable
     */
    readonly logRetention?: RetentionDays;
}
/**
 * @stability stable
 */
export declare class RunTask extends Construct {
    /**
     * @stability stable
     */
    readonly vpc: ec2.IVpc;
    /**
     * @stability stable
     */
    readonly cluster: ecs.ICluster;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: RunTaskProps);
}
